@@ -330,7 +330,7 @@ intergroup_transfer = on_command("金币转移", permission=GROUP, priority=5, b
 
 Market_public = on_command("市场注册",aliases={"公司注册","注册公司"},rule = to_me(),permission=SUPERUSER | GROUP_ADMIN | GROUP_OWNER, priority=5, block=True)
 Market_info = on_command("市场信息",aliases={"查看市场"}, priority=5, block=True)
-Market_info_pro = on_command("市场行情",aliases={"市场走势","市场详细信息"}, permission=GROUP, priority=5, block=True)
+Market_info_pro = on_command("市场行情",aliases={"市场走势","市场详细信息"}, priority=5, block=True)
 company_info = on_command("公司信息",aliases={"公司资料"}, priority=5, block=True)
 
 Market_buy = on_command("买入",aliases={"购买","购入"},permission=GROUP, priority=5, block=True)
@@ -869,10 +869,13 @@ async def _(bot:Bot, event: MessageEvent,arg: Message = CommandArg()):
 
 # 市场走势
 @Market_info_pro.handle()
-async def _(bot:Bot, event: GroupMessageEvent):
-    msg = market_manager.Market_info_pro(event)
+async def _(bot:Bot, event: MessageEvent):
+    msg = await market_manager.Market_info_pro(event)
     if type(msg) == list:
-        await bot.send_group_forward_msg(group_id=event.group_id, messages = msg)
+        if isinstance(event, GroupMessageEvent):
+            await bot.send_group_forward_msg(group_id = event.group_id, messages = msg)
+        else:
+            await bot.send_private_forward_msg(user_id = event.user_id, messages = msg)
         await Market_info_pro.finish()
     else:
         await Market_info_pro.finish(msg)
